@@ -52,12 +52,21 @@ def db_params_from_env(test=False):
     return out
 
 
+@dataclass
+class IndexDefinition:
+    name: str
+    type: str
+    expression: str  # what will be indexed - typically a name of column, but may be more
+    granularity: int = 1
+
+
 @dataclass
 class TableMetaParams:
     engine: str = "CollapsingMergeTree"
     sign_col: str = "sign"
     primary_key: [str] = field(default_factory=list)
     sorting_key: [str] = field(default_factory=list)
+    indexes: [IndexDefinition] = field(default_factory=list)
 
 
 class ClickhouseCubeBackend(CubeBackend):
@@ -308,6 +317,16 @@ class ClickhouseCubeBackend(CubeBackend):
             for dim in list(cube._dimensions.values()) + list(cube._metrics.values())
         ]
         field_part = ", ".join(fields)
+        # indexes
+        indexes = []
+        idx: IndexDefinition
+        for idx in meta.indexes:
+            indexes.append(
+                f"INDEX {idx.name} ({idx.expression}) TYPE {idx.type} GRANULARITY {idx.granularity}"
+            )
+        idx_part = ", ".join(indexes)
+        if idx_part:
+            field_part += ", " + idx_part
         # sorting key
         cube_dim_names = set(cube._dimensions.keys())
         if meta.sorting_key:
